<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['%d association'] = '%d association';
$lang['%d associations'] = '%d associationer';
$lang['%d album including'] = '%d kategori inkluderar';
$lang['%d albums including'] = '%d kategorier inkluderar';
$lang['%d physical'] = ' %d fysisk';
$lang[' and %d virtual'] = ' and %d virituell';
$lang['%d album moved'] = '%d kategori flyttad';
$lang['%d albums moved'] = '%d kategorier flyttade';
$lang['%d group'] = '%d grupp';
$lang['%d groups'] = '%d grupper';
$lang['%d member'] = '%d medlem';
$lang['%d members'] = '%d medlemmar';
$lang['%d tag'] = '%d tagg';
$lang['%d tags'] = '%d taggar';
$lang['%d user comment rejected'] = '%d användares kommentar nekad';
$lang['%d user comments rejected'] = '%d användares kommentarer nekade';
$lang['%d user comment validated'] = '%d användares kommentar godkänd';
$lang['%d user comments validated'] = '%d användares kommentarer godkända';
$lang['%d user deleted'] = '%d användare borttagen';
$lang['%d users deleted'] = '%d användare borttagna';
$lang['%d user'] = '%d användare';
$lang['%d users'] = '%d användare';
$lang['%d waiting for validation'] = '%d väntar på godkännande';
$lang['Actions'] = 'Åtgärder';
$lang['Activate'] = 'Aktivera';
$lang['Add/delete a permalink'] = 'Lägg till/Ta bort en permalink';
$lang['Add a tag'] = 'Lägg till en tagg';
$lang['Add a user'] = 'Lägg till en användare';
$lang['Add group'] = 'Lägg till grupp';
$lang['Add'] = 'Lägg till';
$lang['Allow user registration'] = 'Tillåt användarregistrering';
$lang['Apply to sub-albums'] = 'Använd på underkategorier';
$lang['Associated'] = 'Associerad';
$lang['Batch management'] = 'Mass hantering';
$lang['Caddie management'] = 'Korg hantering';
$lang['Caddie'] = 'Korg';
$lang['Albums authorized thanks to group associations'] = 'Kategorier auktoriserade tack vare grupp associationer';
$lang['Album manual order was saved'] = 'Kategoriernas manuella ordningsföljd är sparad';
$lang['Check for upgrade failed for unknown reasons.'] = 'Sök efter uppdatering misslyckades av okänd anledning.';
$lang['Check for upgrade'] = 'Sök efter uppdatering';
$lang['Comments for all'] = 'Kommentarer för alla';
$lang['Current name'] = 'Aktuellt namn';
$lang['Database'] = 'Databas';
$lang['Deactivate'] = 'Avaktivera';
$lang['Delete Representant'] = 'Ta bort Representant';
$lang['Delete selected tags'] = 'Ta bort markerade taggar';
$lang['Delete selected users'] = 'Ta bort markerade användare';
$lang['Deletions'] = 'Borttagna';
$lang['Deny selected groups'] = 'Neka markerade grupper';
$lang['Deny selected users'] = 'Neka markerad användare';
$lang['Description'] = 'Beskrivning';
$lang['Display options'] = 'Visa alternativ';
$lang['Dissociated'] = 'Skiljd';
$lang['Does not represent'] = 'Representerar inte';
$lang['Edit selected tags'] = 'Ändra markerade taggar';
$lang['Edit tags'] = 'Ändra taggar';
$lang['Email admins when a new user registers'] = 'Sänd mail till admin när en ny användare registreas';
$lang['Email admins when a valid comment is entered'] = 'Sänd mail till admin när en giltig kommentar är inlagd';
$lang['Email admins when a comment requires validation'] = 'Sänd mail till admin när en kommentar väntar på godkännande';
$lang['Environment'] = 'Miljö';
$lang['Form'] = 'Formulär';
$lang['Gallery title'] = 'Galleri titel';
$lang['Grant selected groups'] = 'Tillåt markerade grupper';
$lang['Grant selected users'] = 'Tillåt markerade användare';
$lang['Group name'] = 'Grupp namn';
$lang['Groups'] = 'Grupper';
$lang['Guests'] = 'Gäster';
$lang['History'] = 'Histori';
$lang['Informations'] = 'Information';
$lang['Install'] = 'Installera';
$lang['Link all album photos to a new album'] = 'Länka alla kategori element till en ny kategori';
$lang['Link all album photos to some existing albums'] = 'Länka alla kategori element till existerande kategorier';
$lang['Linked albums'] = 'Länkade kategorier';
$lang['Lock gallery'] = 'Lås galleri';
$lang['Maintenance'] = 'Underhåll';
$lang['Edit album permissions'] = 'Hantera behörigheter för en kategori';
$lang['Manage permissions for group "%s"'] = 'Hantera behörigheter för grupp "%s"';
$lang['Manage permissions for user "%s"'] = 'Hantera behörigheter för användare "%s"';
$lang['Manage tags'] = 'Hantera taggar';
$lang['Members'] = 'Medlemmar';
$lang['Metadata synchronized from file'] = 'Metadata synkroniserad från fil';
$lang['Move albums'] = 'Flytta kategorier';
$lang['Move'] = 'Flytta';
$lang['Name'] = 'Namn';
$lang['New name'] = 'Nytt namn';
$lang['New parent album'] = 'Ny nuvarande kategori';
$lang['New tag'] = 'Ny tagg';
$lang['Number of comments per page'] = 'Antal kommentarer per sida';
$lang['Number of rates'] = 'Antal röster';
$lang['Number of thumbnails to create'] = 'Antal miniatyrer att skapa';
$lang['Only private albums are listed'] = 'Enbart privata kategorier är listade';
$lang['Operating system'] = 'Operativ system';
$lang['Options'] = 'Alternativ';
$lang['Other private albums'] = 'Andra privata kategorier';
$lang['Page banner'] = 'Sidans banner';
$lang['Parent album'] = 'Nuvarande kategori';
$lang['Path'] = 'Sökväg';
$lang['Permalink'] = 'Permalänk';
$lang['Permalink %s has been previously used by album %s. Delete from the permalink history first'] = 'Permalänk %s har tidigare varit använd av kategori %s. Ta bort från permalänks historiken först';
$lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"'] = 'Permalänkens namn får endast innehålla följande tecken: a-z, A-Z, 0-9, "-", "_" eller "/". Den får inte vara numerisk eller börja med ett nummber följt av "-"';
$lang['Permalink %s is already used by album %s'] = 'Permalänk %s används redan av kategori %s';
$lang['Permalink history'] = 'Permalänks historik';
$lang['Permalinks'] = 'Permalänkar';
$lang['Permission denied'] = 'Tillgång nekad';
$lang['Permission granted thanks to a group'] = 'Tillgång beviljad tack vare en grupp';
$lang['Permission granted'] = 'Tillgång beviljad';
$lang['Photo informations updated'] = 'Bild information uppdaterad';
$lang['Plugins'] = 'Plugins';
$lang['Position'] = 'Position';
$lang['Preferences'] = 'Inställningar';
$lang['Properties'] = 'Egenskaper';
$lang['Random photo'] = 'Slumpad bild';
$lang['Rate date'] = 'Röst datum';
$lang['Rating by guests'] = 'Röstning av gäster';
$lang['Rating'] = 'Röstning';
$lang['Reject'] = 'Neka';
$lang['Representant'] = 'Representant';
$lang['Representation of albums'] = 'Kategori representation';
$lang['Representative'] = 'Representativ';
$lang['Represents'] = 'Representerar';
$lang['Save order'] = 'Spara ordning';
$lang['Save to permalink history'] = 'Spara i permalänks historik';
$lang['Select at least one album'] = 'Markera minst en kategori';
$lang['Select at least one photo'] = 'Markera minst en bild';
$lang['Select at least one user'] = 'Markera minst en användare';
$lang['Show info'] = 'Visa info';
$lang['Site manager'] = 'Hantera sidor';
$lang['Status'] = 'Status';
$lang['Statistics'] = 'Statistik';
$lang['Storage album'] = 'Lagrings kategori';
$lang['Sum of rates'] = 'Summa av röster';
$lang['Tag "%s" already exists'] = 'Tagg "%s" existerar redan';
$lang['Tag "%s" was added'] = 'Tagg "%s" har lagts till';
$lang['Tag selection'] = 'Tagg markering';
$lang['The %d following tags were deleted'] = 'Följande %d taggar har blivit borttagna';
$lang['Unable to check for upgrade.'] = 'Fel uppstod under sökning efter uppdatering.';
$lang['Uninstall'] = 'Avinstallera';
$lang['Use the default photo sort order (defined in the configuration file)'] = 'Använd standard ordning för bild sortering (definerad i konfigurationsfilen)';
$lang['User comments validation'] = 'Validera användar kommentarer';
$lang['Users'] = 'Användare';
$lang['Validate'] = 'Godkänn';
$lang['Validation'] = 'Godkänn';
$lang['Version'] = 'Version';
$lang['Virtual albums to move'] = 'Virtuella kategorier att flytta';
$lang['Virtual album name'] = 'Namn på virtuell kategori';
$lang['Webmaster cannot be deleted'] = 'Kan inte ta bort Webmaster';
$lang['You are running on development sources, no check possible.'] = 'Du använder utväcklar källor, kontroll är inte möjlig.';
$lang['You cannot delete your account'] = 'Du kan inte ta bort ditt konto';
$lang['You cannot move an album in its own sub album'] = 'Du kan inte flytta en kategori till sin egen underkategori';
$lang['You need to confirm deletion'] = 'Du måste godkänna borttagning';
$lang['add tags'] = 'lägg till taggar';
$lang['Associate to album'] = 'associera till kategori';
$lang['associate to group'] = 'associera till grupp';
$lang['Authorized'] = 'Befogad';
$lang['Add a virtual album'] = 'Lägg till en virtuell kategori';
$lang['Authorize users to add comments on selected albums'] = 'Tillåt användare att lägga till kommentarer på markerade kategorier';
$lang['The name of an album must not be empty'] = 'Namnet på en kategori kan inte vara blankt';
$lang['Lock albums'] = 'Lås kategorier';
$lang['Private'] = 'Privat kategori';
$lang['Public'] = 'Allmänn ';
$lang['Find a new representant by random'] = 'Hitta en ny slumpad representant';
$lang['Public / Private'] = 'Allmän / Privat';
$lang['Manage authorizations for selected albums'] = 'Hantera behörigheter för markerade kategorier';
$lang['Virtual album added'] = 'Virtuell kategori tillagd';
$lang['Virtual album deleted'] = 'Virtuell kategori borttagen';
$lang['Access type'] = 'Typ av tillgång';
$lang['Comments'] = 'Kommentarer';
$lang['Information data registered in database'] = 'Informations data registrerad i databas';
$lang['Default display'] = 'Standard vy';
$lang['The gallery URL is not valid.'] = 'Adressen till galleriet är ogiltig.';
$lang['Main'] = 'Allmänt';
$lang['The number of comments a page must be between 5 and 50 included.'] = 'Antalet kommentarer per sida måste vara mellan 5 och 50.';
$lang['Configuration'] = 'Inställning';
$lang['confirm'] = 'godkänn';
$lang['Date'] = 'Datum';
$lang['delete album'] = 'ta bort kategori';
$lang['Dissociate from album'] = 'skilj från kategori';
$lang['dissociate from group'] = 'skilj från grupp';
$lang['edit album permissions'] = 'ändra kategori behörigheter';
$lang['Album updated successfully'] = 'Kategori informationen har uppdaterats.';
$lang['photos per page'] = 'Bilder per sida';
$lang['High definition enabled'] = 'High definition aktiverad';
$lang['File'] = 'Fil';
$lang['Filesize'] = 'Filstorlek';
$lang['first photo added on %s'] = 'första elementet tillagt på %s';
$lang['Forbidden'] = 'Förbjudet';
$lang['global mode'] = 'globalt läge';
$lang['group "%s" added'] = 'grupp "%s" tillagd';
$lang['group "%s" deleted'] = 'grupp "%s" borttagen';
$lang['group "%s" updated'] = 'grupp "%s" uppdaterad';
$lang['group'] = 'grupp';
$lang['The name of a group must not contain " or \' or be empty.'] = 'Namnet på en grupp får inte innehålla symbolerna " eller \' eller vara blank.';
$lang['This name is already used by another group.'] = 'Det här namnet används redan av en annan grupp.';
$lang['High definition'] = 'High definition';
$lang['jump to album'] = 'gå till kategori';
$lang['jump to photo'] = 'gå till bild';
$lang['leave'] = 'lämna';
$lang['Lock'] = 'Lås';
$lang['Locked'] = 'Låst';
$lang['manage album photos'] = 'Hantera kategori element';
$lang['manage sub-albums'] = 'Hantera underkategorier';
$lang['Manage'] = 'Hantera';
$lang['maximum height'] = 'Maximal höjd';
$lang['maximum width'] = 'Maximal bredd';
$lang['Execution time is out, treatment must be continue [Estimated time: %d second].'] = 'Processen svarar inte, behandling måste fortsätta [Uppskattad tid: %d sekund].';
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = 'Processen svarar inte, behandling måste fortsätta [Uppskattad tid: %d sekunder].';
$lang['Prepared time for list of users to send mail is limited. Others users are not listed.'] = 'Tid att förbereda listan för användare som ska skickas e-mail är begränsad. Andra användare är inte listade.';
$lang['Time to send mail is limited. Others mails are skipped.'] = 'Tiden att skicka e-mail är begränsad. Andras e-mail hoppas över.';
$lang['To send ?'] = 'Att skicka?';
$lang['Last send'] = 'Senast skickat';
$lang['email'] = 'E-mail';
$lang['User'] = 'Användare';
$lang['Complementary mail content'] = 'Kompletterande mail innehåll';
$lang['See you soon,'] = 'Vi ses,';
$lang['Go to'] = 'Gå till';
$lang['Hello'] = 'Hallå';
$lang['New photos were added'] = 'Nya element har blivit tillagda';
$lang['on'] = 'på';
$lang['between'] = 'mellan';
$lang['and'] = 'och';
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = 'Webmaster har lagt till dig så att du får notifikationer via e-mail.';
$lang['You have subscribed to receiving notifications by mail.'] = 'Du har lagts till och kommer nu får notifikationer via e-mail.';
$lang['To subscribe'] = 'Till prenumerera';
$lang['If you encounter problems or have any question, please send a message to'] = 'Om du stöter på problem eller har frågor, vänligen skicka ett meddelande till';
$lang['[NBM] Problems or questions'] = '[NBM] Problem eller frågor';
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = 'Webmaster har tagit bort dig från listan, du kommer nu inte få några notifikationer via e-mail.';
$lang['You have unsubscribed from receiving notifications by mail.'] = 'Du har blivit borttagen från notifikations e-mail listan.';
$lang[', click on'] = ', klicka på';
$lang['To unsubscribe'] = 'Till avsluta prenumeration';
$lang['With blank value, gallery title will be used'] = 'Om lämnad tom kommer galleriets titel att användas';
$lang['Notification'] = 'Notifikation';
$lang['Error when sending email to %s [%s].'] = 'När försökte skicka e-mail till %s [%s] ett fel uppstod.';
$lang['Mail sent to %s [%s].'] = 'E-mail skickat till %s [%s].';
$lang['%d mail was sent.'] = '%d e-mail har blivit skickat.';
$lang['%d mails were sent.'] = '%d e-mail var skickade.';
$lang['%d mail was not sent.'] = '%d e-mail skickades inte.';
$lang['%d mails were not sent.'] = '%d e-mail skickades inte.';
$lang['No mail to send.'] = 'Inga e-mail att skicka.';
$lang['There is no available subscribers to mail.'] = 'Det finns inga prenumeranter att skicka notifikationer till.';
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = 'Prenumeranter kan listas (tillgänglig) enbart om det finns nya element att meddela.';
$lang['Anyway only webmasters can see this tab and never administrators.'] = 'Ändå, enbart webmaster kan se denna flik, inte administratörer.';
$lang['No user to send notifications by mail.'] = 'Ingen användare att meddela via e-mail.';
$lang['New photos added'] = 'Nya element tillagda';
$lang['Subscribe to notification by mail'] = 'Anmäl till notifikation via e-mail';
$lang['Unsubscribe from notification by mail'] = 'Avanmäl notifikation via e-mail';
$lang['Parameter'] = 'Inställningar';
$lang['Operation in progress'] = 'Bearbetnings behandling.';
$lang['Continue processing treatment'] = 'Fortsätt med pågående behandling';
$lang['Add detailed content'] = 'Lägg till detaljerad information';
$lang['Send mail as'] = 'Skicka e-mail som';
$lang['Send mail to users'] = 'Skicka e-mail till användare';
$lang['Send'] = 'Skicka';
$lang['Subscribed'] = 'Anmäld';
$lang['Subscribe'] = 'Anmäl';
$lang['Parameters'] = 'Parameter';
$lang['Select recipients'] = 'Välj mottagare';
$lang['Subscribe/unsubscribe users'] = 'Anmäl/Avanmäl användare';
$lang['Unsubscribed'] = 'Avanmäld';
$lang['%d parameter was updated.'] = '%d parameter uppdaterad.';
$lang['%d parameters were updated.'] = '%d parameter uppdaterade.';
$lang['%d user was not updated.'] = '%d användare uppdaterades inte.';
$lang['%d users were not updated.'] = '%d användare uppdaterades inte.';
$lang['User %s [%s] was removed from the subscription list.'] = 'Användare %s [%s] borttagen från prenumerations listan.';
$lang['User %s [%s] was added to the subscription list.'] = 'Användare %s [%s] tillagd till prenumerations listan.';
$lang['%d user was updated.'] = '%d användare uppdaterad.';
$lang['%d users were updated.'] = '%d användare uppdaterade.';
$lang['User %s [%s] was not removed from the subscription list.'] = 'Användare %s [%s] inte borttagen från prenumerations listan.';
$lang['User %s [%s] was not added to the subscription list.'] = 'Användare %s [%s] inte tillagd till prenumerations listan.';
$lang['User %s [%s] added.'] = 'Användare %s [%s] tillagd.';
$lang['Warning: subscribing or unsubscribing will send mails to users'] = 'Varning: anmälning eller avanmälning kommer att skicka e-mail till användare';
$lang['Send mail on HTML format'] = 'Skicka e-mail i HTML format';
$lang['Include display of recent photos grouped by dates'] = 'Inkludera display av tidigare bilder grupperat efter datum';
$lang['Available only with HTML format'] = 'Endast tillgänglig med HTML format';
$lang['no write access'] = 'inte tillåtelse att skriva';
$lang['Permissions'] = 'Behörigheter';
$lang['private'] = 'privat';
$lang['public'] = 'allmänt';
$lang['Purge never used notification feeds'] = 'Utrensning använder aldrig notifikations feeds';
$lang['Purge sessions'] = 'Sessioner för utrensning';
$lang['randomly represented'] = 'slumpad representant';
$lang['registration date'] = 'registrerings datum';
$lang['clean'] = 'rensa upp';
$lang['remove remote listing.xml file'] = 'ta bort fjärrlistning .xml fil';
$lang['generate listing'] = 'generera listning';
$lang['generate file listing.xml on remote site'] = 'generera fil listning .xml på fjärrsida';
$lang['Create this site'] = 'Skapa denna sida';
$lang['A local listing.xml file has been found for'] = 'En lokal listing.xml fil har hittats för';
$lang['read local listing.xml and update'] = 'läs lokal listing.xml och uppdatera';
$lang['test'] = 'test';
$lang['test this remote site'] = 'testa fjärrsidan';
$lang['remove tags'] = 'ta bort taggar';
$lang['Repair and optimize database'] = 'Reparera och optimisera databas';
$lang['selection'] = 'markering';
$lang['set to'] = 'inställd på';
$lang['singly represented'] = 'fast representant';
$lang['This site already exists'] = 'Sidan existerar redan';
$lang['Create a new site : (give its URL to create_listing_file.php)'] = 'Skapa ny site : (ge dess URL till create_listing_file.php)';
$lang['created'] = 'skapad';
$lang['delete'] = 'ta bort';
$lang['delete this site and all its attached elements'] = 'ta bort hemsidan och all relaterad information';
$lang['deleted'] = 'borttagen';
$lang['an error happened'] = 'ett fel uppstod';
$lang['file create_listing_file.php on remote site was not found'] = 'fil create_listing_file.php hittades inte på fjärrsidan';
$lang['Local'] = 'Lokal';
$lang['Remote'] = 'Fjärrsida';
$lang['synchronize'] = 'synkronisera';
$lang['update the database from files'] = 'uppdatera databasen med filer';
$lang['status'] = 'status';
$lang['Directory'] = 'Katalog';
$lang['sub-albums'] = 'underkategorier';
$lang['synchronize metadata'] = 'synkronisera metadata';
$lang['target'] = 'mål';
$lang['Thumbnail'] = 'Miniatyr';
$lang['title'] = 'titel';
$lang['Album list management'] = 'Hantera kategorier';
$lang['Piwigo configuration'] = 'Piwigo konfiguration';
$lang['Edit album'] = 'Ändra en kategori';
$lang['Group management'] = 'Grupp hantering';
$lang['User list'] = 'Användarlista';
$lang['Edit photo information'] = 'Modifiera bildinformation';
$lang['Thumbnail creation'] = 'Skapa miniatyrer';
$lang['Database synchronization with files'] = 'Synkronisera databas med filer';
$lang['all'] = 'alla';
$lang['photos without thumbnail (jpeg and png only)'] = 'bilder utan miniatyrbild (enbart jpeg och png)';
$lang['height must be a number superior to'] = 'bildens höjd måste vara större än';
$lang['width must be a number superior to'] = 'bildens bredd måste vara större än';
$lang['for the file format'] = 'för filformatet';
$lang['No missing thumbnail'] = 'Inga miniatyrbilder saknas';
$lang['Photo unreachable or no support'] = 'Bilden kunde inte nås eller filformatet stöds inte';
$lang['GD version'] = 'GD version';
$lang['Miniaturization parameters'] = 'Miniatyriserings parametrar';
$lang['generated in'] = 'generering tog';
$lang['Results of miniaturization'] = 'Resultat av miniatyriserings process';
$lang['General statistics'] = 'Allmän statistik';
$lang['max time'] = 'max tid';
$lang['average time'] = 'snitt tid';
$lang['min time'] = 'min tid';
$lang['number of miniaturized photos'] = 'antal miniatyrer skapade';
$lang['total time'] = 'total tid';
$lang['for this file format'] = 'för detta filformat';
$lang['unit mode'] = 'enkel läge';
$lang['Unlocked'] = 'Upplåst';
$lang['unset'] = 'obestämd';
$lang['Update albums informations'] = 'Uppdatera information för kategori';
$lang['Update photos information'] = 'Uppdatera information för bilder';
$lang['Synchronize'] = 'Synkronisera';
$lang['reduce to single existing albums'] = 'reducera till enstaka existerande kategorier';
$lang['Choose an option'] = 'Välj ett alternativ';
$lang['display maximum informations (added albums and photos, deleted albums and photos)'] = 'visa maximal information (tillagda kategorier och element, borttagna kategorier och element)';
$lang['Piwigo version differs on the remote site'] = 'Versionen av Piwigo skiljer sig från den på fjärrsidan';
$lang['Version of create_listing_file.php on the remote site and Piwigo must be the same'] = 'Versionen av create_listing_file.php måste vara samma på fjärrsidan och Piwigo måste vara samma';
$lang['listing.xml file was not found'] = 'listing.xml kunde inte hittas';
$lang['listing.xml file was not found on the remote site. This file is generated by choosing the "generate listing" command in the Site manager'] = 'filen listing.xml hittades inte på fjärrsidan. Denna fil är genererad med "generera listning" kommandot i Site hanteraren';
$lang['Error list'] = 'Fel lista';
$lang['Errors caption'] = 'Fel legender';
$lang['Detailed informations'] = 'Detaljerad information';
$lang['File/directory read error'] = 'Läs fel i fil/katalog';
$lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = 'Filen eller katalogen kan inte nås (antigen existerar den inte eller tillträde nekat)';
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = 'filtypen för en bild måste ha en miniatyrbild. En miniatyrbild måste finnas i en undermapp för kategorien. Namnet på mappen måste vara "thumbnail". Miniatyrbildens filnamn måste börja med det förkonfigurerade prefixet och anslutningen måste finnas i följande lista :';
$lang['missing thumbnail'] = 'miniatyrbild saknas';
$lang['albums deleted in the database'] = 'kategorier borttagna ur databasen';
$lang['photos deleted from the database'] = 'element borttagna ur databasen';
$lang['photos candidates for metadata synchronization'] = 'bild kandidater för metadata synkronisering';
$lang['photos informations synchronized with files metadata'] = 'element informationer synkroniserade med filernas metadata';
$lang['errors during synchronization'] = 'fel uppstod under synkronisering';
$lang['albums added in the database'] = 'kategorier tillagda i databas';
$lang['photos added in the database'] = 'element tillagda i databasen';
$lang['photos updated in the database'] = 'element i databasen uppdaterade';
$lang['Search for new images in the directories'] = 'Sök i katalogerna efter nya bilder';
$lang['added'] = 'tillagd';
$lang['Metadata synchronization results'] = 'Resultat för synkronisering av metadata';
$lang['only perform a simulation (no change in database will be made)'] = 'Utför enbart simulering (inget kommer att ändras i databasen)';
$lang['[Simulation]'] = '[Simulering]';
$lang['Simulation'] = 'Simulering';
$lang['directories + files'] = 'Kataloger + filer';
$lang['only directories'] = 'bara kataloger';
$lang['synchronize files structure with database'] = 'synkronisera filstruktur med databas';
$lang['synchronize files metadata with database photos informations'] = 'synkronisera databas element med filernas metadata';
$lang['even already synchronized photos'] = 'även redan synkroniserade element';
$lang['Used metadata'] = 'Metadata Använd';
$lang['The name of directories and files must be composed of letters, numbers, "-", "_" or "."'] = 'Namn på kataloger och filer får enbart innehålla bokstäver, siffror samt följande symboler: "-", "_" eller "."';
$lang['wrong filename'] = 'ogiltigt filnamn';
$lang['Upload'] = 'Ladda upp';
$lang['user "%s" added'] = 'Användare "%s" tillagd';
$lang['User status'] = 'Användares status';
$lang['user_status_admin'] = 'Administratör';
$lang['user_status_generic'] = 'Generisk';
$lang['user_status_guest'] = 'Gäst';
$lang['user_status_normal'] = 'Användare';
$lang['user_status_webmaster'] = 'Webmaster';
$lang['Virtual album'] = 'Virtuell kategori';
$lang['Waiting'] = 'Väntande';
$lang['default'] = 'standard';
$lang['Toggle \'default group\' property'] = 'Omvänd egenskap för \'standard grupp\' ';
$lang['Advanced features'] = 'Avancerade funktioner';
$lang['Specials'] = 'Extra';
$lang['Overall'] = 'Översikt';
$lang['Year'] = 'År';
$lang['Month'] = 'Månad';
$lang['Day'] = 'Dag';
$lang['Pages seen'] = 'Sidor sedda';
$lang['Time'] = 'Tid';
$lang['IP'] = 'IP';
$lang['Element'] = 'Element';
$lang['Section'] = 'Sektion';
$lang['Tags'] = 'Taggar';
$lang['Save page visits by guests'] = 'Registrera sidor besökta av gäster';
$lang['Save page visits by users'] = 'Registrera sidor besökta av användare';
$lang['Save page visits by administrators'] = 'Registrera sidor besökta av administratörer';
$lang['An information email was sent to group "%s"'] = 'E-mail med information skickat till grupp "%s"';
$lang['Send an information email to group members'] = 'Skicka e-mail med information till medlemmar i grupp';
$lang['Group'] = 'Grupp';
$lang['[%s] Visit album %s'] = '[%s] Besök kategori %s';
$lang['Hello,'] = 'Hallå,';
$lang['See you soon.'] = 'Vi ses.';
$lang['Discover album:'] = 'Utforska kategori:';
$lang['Mail content'] = 'E-mail innehåll';
$lang['none'] = 'inget';
$lang['high'] = 'hög';
$lang['other'] = 'annan';
$lang['Element type'] = 'Typ av element';
$lang['Image id'] = 'Bild id';
$lang['Summary'] = 'Sammanfattning';
$lang['%d line filtered'] = '%d rad filtrerad';
$lang['%d lines filtered'] = '%d rader filtrerade';
$lang['%d guest'] = '%d gäst';
$lang['%d guests'] = '%d gäster';
$lang['Hour'] = 'Timme';
$lang['guest'] = 'gäst';
$lang['default values'] = 'standardvärden';
$lang['High filesize'] = 'Hög upplösning filstorlek';
$lang['Guest cannot be deleted'] = 'Gäst kan inte tas bort';
$lang['Default user cannot be deleted'] = 'Standard användare kan inte tas bort';
$lang['Purge history detail'] = 'Rensa histori detaljer';
$lang['Purge history summary'] = 'Rensa historik sammanställning';
$lang['Check integrity'] = 'Integritets kontroll';
$lang['Anomaly'] = 'Avvikelse';
$lang['Correction'] = 'Rättning';
$lang['Automatic correction'] = 'Automatisk rättning';
$lang['Impossible automatic correction'] = 'Automatisk rättning var inte möjlig';
$lang['Correction applied with success'] = 'Rättning utfördes med framgång';
$lang['Correction applied with error'] = 'Rättning utfördes men med fel';
$lang['%d anomaly has been detected.'] = '%d avvikelse har upptäckts.';
$lang['%d anomalies have been detected.'] = '%d avvikelser har upptäckts.';
$lang['%d anomaly has been corrected.'] = '%d avvikelse har rättats.';
$lang['%d anomalies have been detected corrected.'] = '%d avvikelser har upptäckts och rättats.';
$lang['%d anomaly has not been corrected.'] = '%d avvikelse kunde inte rättats.';
$lang['%d anomalies have not been corrected.'] = '%d avvikelser kunde inte rättas.';
$lang['Go to %s or %s for more informations'] = 'Gå till %s eller %s för mer information';
$lang['the forum'] = 'forumet';
$lang['the wiki'] = 'wiki';
$lang['%s value is not correct file because exif are not supported'] = '%s värde är inkorrekt eftersom att exif inte stöds';
$lang['%s must be to set to false in your local/config/config.inc.php file'] = '%s Måste ställas in på negativ i följande fil : your local/config/config.inc.php';
$lang['Main "guest" user does not exist'] = 'Huvudanvändare "gäst" är inte korrekt';
$lang['Main "guest" user status is incorrect'] = 'Huvudanvändare "gäst" är inte korrekt';
$lang['Default user does not exist'] = 'Standard användare existerar inte';
$lang['Main "webmaster" user does not exist'] = 'Huvudanvändare "webmaster" existerar inte';
$lang['Main "webmaster" user status is incorrect'] = 'Huvudanvändare "webmaster" status är inkorrekt';
$lang['User "%s" created with "%s" like password'] = 'Användare "%s" skapades med "%s" som lösenord';
$lang['Status of user "%s" updated'] = 'Användare "%s" status uppdaterad';
$lang['add new photos to caddie'] = 'lägg till nytt element till korg';
$lang['No display'] = 'Inget att visa';
$lang['Classic display'] = 'Klassisk visning';
$lang['Hoverbox display'] = 'Hoverbox visning';
$lang['Mail address is obligatory for all users'] = 'Mail adress är obligatorisk för alla användare';
$lang['Minimum privacy level'] = 'Minimum privat nivå';
$lang['Privacy level'] = 'Privat nivå';
$lang['Level 0'] = '---';
$lang['Level 1'] = 'Kontakter';
$lang['Level 2'] = 'Vänner';
$lang['Level 4'] = 'Familj';
$lang['Level 8'] = 'Administratörer';
$lang['Reinitialize check integrity'] = 'Återinitialisera integritetskontroll';
$lang['Check all'] = 'Kontrollera alla';
$lang['Uncheck all'] = 'Avmarkera alla';
$lang['Check automatic corrections'] = 'Kontrollera automatiska rättningar';
$lang['Apply selected corrections'] = 'Tillämpa markeradApply selected corrections';
$lang['Ignore selected anomalies'] = 'Ignorera markerade avvikelser';
$lang['Refresh'] = 'Uppdatera';
$lang['The anomaly will be ignored until next application version'] = 'Avvikelsen kommer att ignoreras tills nästa version av applikationen';
$lang['Correction the anomaly will cancel the fact that it\'s ignored'] = 'Rättad avvikelse kommer inte längre att ignoreras';
$lang['%d anomaly has been ignored.'] = '%d avvikelse ignorerades.';
$lang['%d anomalies have been ignored.'] = '%d avvikelser ignorerades.';
$lang['Plugins which need upgrade'] = 'Plugins som behöver uppdateras';
$lang['Plugin list'] = 'Lista över plugin';
$lang['Check for updates'] = 'Sök efter uppdateringar';
$lang['Other plugins'] = 'Andra plugin tillgängliga';
$lang['Last revisions'] = 'Senaste ändringar';
$lang['Delete'] = 'Ta bort';
$lang['Are you sure you want to delete this plugin?'] = 'Är du säker på att du vill ta bort detta plugin?';
$lang['Are you sure you want to install this plugin?'] = 'Är du säker på att du vill installera detta plugin?';
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = 'Är du säker på att du vill installera uppdateringen? Du måste verifiera nedan att denna version inte behöver yterligare avinstallering.';
$lang['%s has been successfully upgraded.'] = '%s har uppdaterats med framgång.';
$lang['Plugin has been successfully copied'] = 'Kopiering av detta plugin utfördes med framgång';
$lang['You might go to plugin list to install and activate it.'] = 'Gå till plugin listan för att installera och aktivera.';
$lang['Can\'t create temporary file.'] = 'Tillfällig fil kunde inte skapas.';
$lang['Can\'t download archive.'] = 'Arkiv kan inte laddas ner.';
$lang['Can\'t read or extract archive.'] = 'Arkiv kunde inte läsas eller extraheras.';
$lang['An error occured during extraction (%s).'] = 'Ett fel uppstod när följande filer packades upp: (%s).';
$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = 'Kontrollera "plugins" mapp och eventuella undermappars behörigheter (CHMOD).';
$lang['Can\'t connect to server.'] = 'Kunde inte ansluta till servern.';
$lang['Purge compiled templates'] = 'Rensa sammanställda mallar (templates)';
$lang['ACCESS_0'] = 'Fritt tillträde';
$lang['ACCESS_1'] = 'Tillgänglighet för alla';
$lang['ACCESS_2'] = 'Tillgänglighet för registrerade användare';
$lang['ACCESS_3'] = 'Tillgänglighet för administratörer';
$lang['ACCESS_4'] = 'Tillgänglighet för webmasters';
$lang['ACCESS_5'] = 'Ingen tillgänglighet';
$lang['Support'] = 'Hjälp';
$lang['Documentation'] = 'Dokumentation';
$lang['A new version of Piwigo is available.'] = 'En ny version av Piwigo finns nu tillgänglig.';
$lang['Piwigo Administration'] = 'Piwigo Administration';
$lang['Piwigo version'] = 'Piwigo version';
$lang['You are running the latest version of Piwigo.'] = 'Du använder senaste versionen av Piwigo.';
$lang['The version of %s [%s] installed is not compatible with the version required [%s]'] = 'Versionen av %s [%s] installerad är inte kompatibel med versionen som krävs [%s]';
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = 'För att utnyttja alla fördelar av programmet, uppdatera ditt system, annars kan det resultera i att programmet inte fungerar korrekt eller inte alls';
$lang['Deleted on'] = 'Borttagen den';
$lang['Last hit'] = 'Senaste träff';
$lang['GD library is missing'] = 'GD bibliotek saknas';
$lang['Templates'] = 'Mallar (Templates)';
$lang['Extend for templates'] = 'Utvidga mallar (templates)';
$lang['Replacement of original templates by customized templates from template-extension subfolder'] = 'Ersättning av original mallar (templates) av special anpassade mallar från "template-extension" undermappen';
$lang['Replacers (customized templates)'] = 'Substitut (anpassade mallar)';
$lang['Original templates'] = 'Standard mallar';
$lang['Optional URL keyword'] = 'Standard URL nyckelord';
$lang['Templates configuration has been recorded.'] = 'Konfiguerering av mallar har registrerats.';
$lang['All optimizations have been successfully completed.'] = 'Alla optimeringar har slutförts.';
$lang['Optimizations have been completed with some errors.'] = 'Optimeringar har slutförts, men fel uppstod.';
$lang['Modify information'] = 'Modifiera information';
$lang['edit album'] = 'Ändra information för denna kategori';
$lang['nothing'] = 'inget';
$lang['overrides existing values with empty ones'] = 'skriver över existerande värden med tomma värden';
$lang['manage photo ranks'] = 'hantera bild betygsättning';
$lang['Manage photo ranks'] = 'Hantera bild betygsättning';
$lang['Edit ranks'] = 'Ändra betygsättning';
$lang['No photo in this album'] = 'Inga element i denna kategori';
$lang['Images manual order was saved'] = 'Manuell bild ordning sparad';
$lang['ranks'] = 'betyg';
$lang['By rank'] = 'Efter betyg';
$lang['Manual order'] = 'Manuell order';
$lang['Drag to re-order'] = 'Tryck-och-dra för att ändra ordning';
$lang['Quick Local Synchronization'] = 'Snabb Lokal Synkronisering';
$lang['No photo can be deleted'] = 'Inga foton kan tas bort';
$lang['Delete selected photos'] = 'Ta bort markerade foton';
$lang['%d photo was deleted'] = '%d foto borttaget';
$lang['%d photos were deleted'] = '%d foton borttagna';
$lang['Downloads'] = 'Nerladdningar';
$lang['Released on'] = 'Släppt den';
$lang['Number of downloads'] = 'Antal nerladdningar';
$lang['Piwigo Announcements Newsletter'] = 'Piwigo Nyhetsbrev';
$lang['Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will receive emails when a new release is available (sometimes including a security bug fix, it\'s important to know and upgrade) and when major events happen to the project. Only a few emails a year.'] = 'Håll dig uppdaterad på Piwigo projektet, anmäl dig till Piwigo nyhetsbrev. Ett e-mail kommer att skickas till dig så fort en ny uppdatering är tillgänglig (innehållande säkerhetsuppdateringar, bug fix och saker som är viktiga för säkerheten av ditt galleri) och vid viktiga händelser. Enbart några få e-mail varje år.';
$lang['Subscribe %s'] = 'Anmäl %s';
$lang['Subscribe %s to Piwigo Announcements Newsletter'] = 'Anmäl dig %s till Piwigo Nyhetsbrev';
$lang['Purge search history'] = 'Rensa sökhistorik';
$lang['Hide'] = 'Göm';
$lang['Password is missing. Please enter the password.'] = 'Lösenord saknas. Ange lösenord.';
$lang['Password confirmation is missing. Please confirm the chosen password.'] = 'Bekräftelse av lösenord saknas. Vänligen bekräfta ditt valda lösenord.';
$lang['Password confirmation error.'] = 'Fel uppstod när lösenord skulle bekräftas.';
$lang['Allow users to edit their own comments'] = 'Tillåt användare att ändra egna kommentarer';
$lang['Allow users to delete their own comments'] = 'Tillåt användare att ta bort egna kommentarer';
$lang['Email administrators when a comment is modified'] = 'Notifiera administratör när en kommentar läggs till';
$lang['Email administrators when a comment is deleted'] = 'Notifiera administratör när kommentar tas bort';
$lang['Cannot delete the old permalink !'] = 'Kan inte ta bort gammal permalänk!';
$lang['Hit'] = 'Träff';
$lang['Tools'] = 'Verktyg';
$lang['Photos'] = 'Foton';
$lang['Themes'] = 'Teman';
$lang['Instructions to use Piwigo'] = 'Instruktioner för användning av Piwigo';
$lang['Installed Themes'] = 'Installerade Teman';
$lang['Add New Theme'] = 'Lägg till nytt tema';
$lang['Forbid this theme to users'] = 'Förbjud detta tema för användare';
$lang['Set as default theme for unregistered and new users'] = 'Ange som standard tema för oregistrerade och nya användare';
$lang['unknown'] = 'okänd';
$lang['Upload Photos'] = 'Ladda upp foton';
$lang['Drop into album'] = 'Släpp in i kategori';
$lang['+ Add an upload box'] = '+ Lägg till en uppladdningsruta';
$lang['Create the "%s" directory at the root of your Piwigo installation'] = 'Skapa meppen "%s" i rotkatalogen för din Piwigo installation';
$lang['Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'] = 'Ge tillåtelse att skriva (chmod 777) i mappen "%s" i rotkatalogen för din Piwigo installation';
$lang['existing album'] = 'existerande kategori';
$lang['create a new album'] = 'skapa ny kategori';
$lang['Album name'] = 'Namn på kategori';
$lang['Album "%s" has been added'] = 'Kategori "%s" har lagts till';
$lang['Uploaded Photos'] = 'Uppladdade Foton';
$lang['%d photos uploaded'] = '%d foton uppladdade';
$lang['Privacy level set to "%s"'] = 'Sekretessnivå inställd på "%s"';
$lang['Album "%s" now contains %d photos'] = 'Kategir "%s" innehåller nu %d foton';
$lang['Manage this set of %d photos'] = 'Hantera settet om %d foton';
$lang['Select files'] = 'Markerade filer';
$lang['Everybody'] = 'Alla';
$lang['Who can see these photos?'] = 'Vem kan se dessa foton?';
$lang['Who can see this photo?'] = 'Vem kan se detta foto?';


$lang['The websize maximum width must be a number between %d and %d'] = 'Webstorlekens maximala bredd måste vara ett nummer mellan %d och %d';
$lang['The websize maximum height must be a number between %d and %d'] = 'Webstorlekens maximala höjd måste vara ett nummer mellan %d och %d';
$lang['The websize image quality must be a number between %d and %d'] = 'Webstorlekens bildkvalitet måste vara ett nummer mellan %d och %d';
$lang['The thumbnail maximum width must be a number between %d and %d'] = 'Miniatyrbildens maximala bredd måste vara ett nummer mellan %d och %d';
$lang['The thumbnail maximum height must be a number between %d and %d'] = 'Miniatydbildens maximala höjd måste vara ett nummer mellan %d och %d';
$lang['The thumbnail image quality must be a number between %d and %d'] = 'Miniatydbildens kvalitet måste vara ett nummer mellan %d och %d';
$lang['Settings'] = 'Inställningar';
$lang['Web size photo'] = 'Webstorleks foto';
$lang['Resize'] = 'Ändra storlek';
$lang['Maximum Width'] = 'Maximal Bredd';
$lang['pixels'] = 'pixlar';
$lang['Maximum Height'] = 'Maximal höjd';
$lang['Image Quality'] = 'Bild kvalitet';
$lang['Thumbnail'] = 'Miniatyrbild';
$lang['Save Settings'] = 'Spara inställningar';
$lang['Your configuration settings are saved'] = 'Dina inställningar är nu sparade';

$lang['Active Themes'] = 'Aktivta Teman';
$lang['Add write access to the "%s" directory'] = 'Lägg till skrivrättigheter till "%s" katalogen';
$lang['Administration Home'] = 'Administration Hem';
$lang['Change Admin Colors'] = 'Ändra administrations färger';
$lang['Delete this theme'] = 'Ta bort temat';
$lang['Directory does not exist'] = 'Katalog existerar inte';
$lang['Download,'] = 'Ladda ner,';
$lang['FTP + Synchronization'] = 'FTP + Synkronisering';
$lang['Get Support on Piwigo Forum'] = 'Support hittar du på Piwigo forum';
$lang['Help Me'] = 'Hjälp mig';
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'Temat kunde inte aktiveras, följande tema verkar inte existera: %s';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'Temat kunde inte tas bort, andra teman är beroende av det: %s';
$lang['Inactive Themes'] = 'Inaktivera teman';
$lang['Install on your computer,'] = 'Installera på din dator,';
$lang['Make this theme available to users'] = 'Gör temat tillgängligt för användare';
$lang['Page end'] = 'Slut av sidan';
$lang['Piwigo Uploader'] = 'Piwigo Uppladdare';
$lang['Operation in progress'] = 'Behandling av bearbetning.';
$lang['Please wait...'] = 'Vänligen vänta...';
$lang['Read Piwigo Documentation'] = 'Läs Piwigo Dokumentation';
$lang['Start pLoader and add your photos.'] = 'Starta pLoader och lägg till dina bilder.';
$lang['Switch to clear or dark colors for administration'] = 'Byt till klara eller mörka färger för administration';
$lang['Theme has been successfully installed'] = 'Temat har installerats';
$lang['Visit Gallery'] = 'Besök galleriet';
$lang['Visit Piwigo project website'] = 'Besök Piwigo projekts hemsida';
$lang['pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.'] = 'pLoader står för <em>Piwigo Uploader</em>. pLoader förbereder bilder från din dator och laddar upp dom i ditt Piwigo galleri.';
$lang['Guest Settings'] = 'Gäst inställningar';
$lang['Main Page'] = 'Huvudsida';
$lang['Photo Page'] = 'Fotosida';
$lang['Activate Navigation Bar'] = 'Aktivera navigeringsfältet';
$lang['Activate Navigation Thumbnails'] = 'Aktivera navigations miniatyrer';
$lang['Activate icon "%s"'] = 'Aktivera ikon "%s"';
$lang['Activate field "%s"'] = 'Aktivera fält "%s"';
$lang['Photo Properties'] = 'Foto inställningar';
$lang['Allow user customization'] = 'Tillåt användaranpassning';
$lang['Languages'] = 'Språk';
$lang['Installed Languages'] = 'Installerade Språk';
$lang['Add New Language'] = 'Lägg till nytt språk';
$lang['Language has been successfully installed'] = 'Språket har installerats';
$lang['Select:'] = 'Markera:';
$lang['None'] = 'Inget';
$lang['Invert'] = 'Invertera';
$lang['Impossible to deactivate this theme, you need at least one theme.'] = 'Det går inte att inaktivera detta tema, minst ett tema måste vara aktiverat.';
$lang['Webmaster status is required.'] = 'Webmaster status krävs.';
$lang['Bound Theme'] = 'Bundet Tema';
$lang['Allow rating'] = "Tillåt röstning";
$lang['Select at least one comment'] = 'Markera minst en kommentar';
$lang['Active Plugins'] = 'Aktivera Plugin';
$lang['Inactive Plugins'] = 'Inaktivera Plugin';
$lang['Missing Plugins'] = 'Plugin som saknas';
$lang['Uninstalled Plugins'] = 'Avinstallerade Plugin';
$lang['By %s'] = 'Av %s';
$lang['Visit plugin site'] = 'Besök hemsida för plugin';
$lang['Active Languages'] = 'Aktiva Språk';
$lang['Delete this language'] = 'Ta bort språket';
$lang['Forbid this language to users'] = 'Förbjud språket för användare';
$lang['Impossible to deactivate this language, first set another language as default.'] = 'Det är inte möjligt att inaktivera detta språk, först ange ett annat språk som standard.';
$lang['Impossible to deactivate this language, you need at least one language.'] = 'Det är inte möjligt att inaktivera detta språk, du måste ha minst ett språk.';
$lang['Inactive Languages'] = 'Inaktivera språk';
$lang['Make this language available to users'] = 'Gör detta språk tillgängligt för användare';
$lang['Set as default language for unregistered and new users'] = 'Ange som standard språk för oregistrerade och nya användare';
$lang['Add Photos'] = 'Lägg till foton';
$lang['Download'] = 'Ladda ner';
$lang['The following tag was deleted'] = 'Följande tagg blev borttagen';
$lang['Miscellaneous'] = 'Diverse';
$lang['Virtual Links'] = 'Virtuella Länkar';
$lang['There is no other language available.'] = 'Det finns inget annat språk tillgängligt.';
$lang['There is no other plugin available.'] = 'Det finns inget annat plugin tillgängligt.';
$lang['There is no other theme available.'] = 'Det finns inget annat tema tillgängligt.';
$lang['Add another set of photos'] = 'Lägg till en ny uppsättning foton';
$lang['Order of menubar items has been updated successfully.'] = 'Ordningen för objekt i menyraden har blivit uppdaterad.';
$lang['This theme was not designed to be directly activated'] = 'Detta tema är inte anpassat för att bli direkt aktiverat';
$lang['Pending Comments'] = 'Väntande Kommentarer';
$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = 'I din php.ini fil, upload_max_filesize (%sB) är större än post_max_size (%sB), du rekomenderas att ändra detta';
$lang['Exif extension not available, admin should disable exif use'] = 'Exif extension är inte tillgänglig, admin borde avaktivera användandet av exif';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'Den uppladdade filen överskrider upload_max_filesize direktionerna i php.ini: %sB';
$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = 'Den uppladdade filen överskrider post_max_size direktionerna i php.ini: %sB';
$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = 'Den uppladdade filen överskrider MAX_FILE_SIZE direktiv som var specifierat i HTML form';
$lang['The uploaded file was only partially uploaded'] = 'Den uppladdade filen blev bara delvis uppladdad';
$lang['No file was uploaded'] = 'Ingen fil laddades upp';
$lang['Missing a temporary folder'] = 'Saknar en temporär mapp';
$lang['Failed to write file to disk'] = 'Kunde inte skriva filen till skivan';
$lang['File upload stopped by extension'] = 'Uppladdning av filen stoppades av en extension';
$lang['Unknown upload error'] = 'Okänt fel uppstod under uppladdning';
$lang['Error on file "%s" : %s'] = 'Fel på fil "%s" : %s';
$lang['Menu Management'] = 'Hantera menyer';
$lang['automatic order'] = 'automatisk beställning';
$lang['manual order'] = 'manuell beställning';
$lang['Albums automatically sorted'] = 'Album sorteras automatiskt';
$lang['Keep high definition'] = 'Behåll högupplösing';
$lang['The high definition maximum width must be a number between %d and %d'] = 'Den högupplösta bildens maximal bredd måste vara ett tal mellan %d och %d';
$lang['The high definition maximum height must be a number between %d and %d'] = 'Den högupplösta bildens maximal höjd måste vara ett tal mellan %d and %d';
$lang['The high definition image quality must be a number between %d and %d'] = 'Den högupplösta bildkvalitet måste vara ett tal mellan %d and %d';
$lang['Batch Manager'] = 'Batch hanteraren';
$lang['include child albums'] = 'innefattar under album';
$lang['Selection'] = 'Urval';
$lang['Action'] = 'Åtgärd';
$lang['Set author'] = 'Ange författare';
$lang['Set title'] = 'Sätt rubriken';
$lang['Set creation date'] = 'Sätt datum för skapande';
$lang['Apply action'] = 'Utför åtgärder';
$lang['on the %d selected photos'] = 'på %d valda bilder';
$lang['%d of %d photos selected'] = '%d av %d markerade bilder';
$lang['No photo selected, %d photos in current set'] = 'Inga bilder markerat, %d bilder i aktuella uppsättningen';
$lang['All %d photos are selected'] = 'Alla %d bilder väljs';
$lang['remove this filter'] = 'Ta bort det här filtret';
$lang['predefined filter'] = 'förinställt filter';
$lang['last import'] = 'senaste import';
$lang['with no virtual album'] = 'utan virtuellt album';
$lang['duplicates'] = 'dubbletter';
$lang['Add a filter'] = 'Lägg till ett filter';
$lang['Remove all filters'] = 'Ta bort alla filter';
$lang['Refresh photo set'] = 'Uppdatera bilder';
$lang['The whole page'] = 'Hela sidan';
$lang['The whole set'] = 'Hela markeringen';
$lang['No photo in the current set.'] = 'inga bilder i den aktuella markeringen..';
$lang['No photo selected, no action possible.'] = 'Inga foton är valda, inga åtgärder är möjlig.';
$lang['Choose an action'] = 'Välj en åtgärd';
$lang['remove author'] = 'ta bort författaren';
$lang['Type here the author name'] = 'Skriv författarens namn här';
$lang['remove title'] = 'Ta bort rubriken';
$lang['Type here the title'] = 'Skriv rubriken här';
$lang['remove creation date'] = 'Ta bort skapande datum ';
$lang['with no album'] = 'utan album';
$lang['with no tag'] = 'utan tagg';
$lang['Album photos associated to the following albums: %s'] = 'Album bilder associerade till följande album: %s';
$lang['Delete orphan tags'] = 'Ta bort anonyma taggar';
$lang['delete photo'] = 'Ta bort bild';
$lang['Orphan tags deleted'] = 'Anonyma taggar är readerade';
$lang['Week starts on'] = 'Veckan börjar på';
$lang['You have %d orphan tags: %s.'] = 'Du har %d anonyma taggar: %s.';
$lang['Remove from caddie'] = 'Ta bort från korg';
$lang['Themes which need upgrade'] = 'Teman som behöver uppgraderas';
$lang['Languages which need upgrade'] = 'Språk som behöver uppgradera';
$lang['All themes are up to date.'] = 'Alla teman är uppdaterade.';
$lang['All plugins are up to date.'] = 'Alla plugins are up to date.';
$lang['All languages are up to date.'] = 'Alla språk är aktuella.';
$lang['Visit theme site'] = 'Besök temats webbplats';
$lang['Visit language site'] = 'Besök språkets webbplats';
$lang['New Version'] = 'Ny version';
$lang['Obsolete Plugins'] = 'Föråldrade Plugins';
$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = 'VARNING! Detta plugin verkar inte vara kompatibla med denna version av Piwigo.';
$lang['Do you want to activate anyway?'] = 'Vill du aktivera ändå?';
$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'Detta plugin är nu del av PIWIGO CORE! Avinstallera det NU!';
$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'FEL:. Detta plugin saknas men den är installerad! Avinstallera det NU'; 
$lang['display'] = 'Visa';
$lang['Regenerate Thumbnails'] = 'Generera miniatyrer bilder';
$lang['Thumbnails generation in progress...'] = 'generering av miniatyr bilder pågår ......';
$lang['%s thumbnails have been regenerated'] = '%s miniatyrbilder har skapats';
$lang['%s thumbnails can not be regenerated'] = '%s miniatyrbilder inte kan skapas ';
$lang['Regenerate Websize Photos'] = 'Skapa Web storleks bilder';
$lang['Photos generation in progress...'] = 'Bild generering pågår..';
$lang['%s photos have been regenerated'] = '%s foton har skapats';
$lang['%s photos can not be regenerated'] = '%s foton har inte skapats';
$lang['new'] = 'ny';
$lang['No results'] = 'Inga poster hittades';
$lang['Searching...'] = 'Söker...';
$lang['Type in a search term'] = 'Ange nytt sökord';
$lang['Activate icon "new" next to albums and pictures'] = 'Aktivera ikonen "ny" intill album och bilder';
$lang['Deactivate all'] = 'Avaktivera allt';
$lang['Default photos order'] = 'Standardordning för bilder';
$lang['Restore'] = 'Återställ';
$lang['Restore default configuration. You will lose your plugin settings!'] = 'Återställ standardkonfiguration. Du kommer att förlora inställingarna för din plugins!';
$lang['Show menubar'] = 'Visa verktygsfält';
$lang['Updates'] = 'Uppdateringar';
$lang['Update in progress... Please wait.'] = 'Uppdatering körs... Var vänlig vänta.';
$lang['Ignore this update'] = 'Ignorera denna uppdatering';
$lang['Reset ignored updates'] = 'Nollställ ignorerade uppdateringar';
$lang['Update All'] = 'Uppdatera allt';
$lang['ERROR'] = 'FEL';
$lang['Update Complete'] = 'Uppdatering avslutad';
$lang['Piwigo Update'] = 'Piwigo Uppdatering';
$lang['Extensions Update'] = 'Uppdatering av tillägg';
$lang['Rate'] = 'Betygsätt';
$lang['Average rate'] = 'Genomsnittligt betyg';
$lang['Learn more'] = 'Läs mer';
$lang['Some upgrades are available for extensions.'] = 'Det finns uppdateringar till några insticksmoduler.';
$lang['Ignore All'] = 'Ignorera alla';
$lang['Crop'] = 'Klipp';
$lang['Width'] = 'Bredd';
$lang['Height'] = 'Höjd';
$lang['Follow Orientation'] = 'Följ bildformat';
$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Om du vill regenerera miniatyrerna, på till <a href="%s">Batch Manager</a>.';
$lang['Graphics Library'] = 'Grafikbibliotek';
$lang['... or '] = '... eller ';
$lang['Create'] = 'Skapa';
$lang['Start Upload'] = 'Börja uppladdning';
$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'Du använder Flash-uppladaren. Har du problem, försök med <a href="%s">webbläsaruppladdaren</a> istället.';
$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'Du använder webbläsaruppladdaren, prova gärna <a href="%s">Flash-uppladdaren</a> istället.';
$lang['Maximum file size: %sB.'] = 'Maximal filstorlek: %sB.';
$lang['Allowed file types: %s.'] = 'Tillåtna filtyper: %s.';
$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'Ungefärlig maximal upplösning: %dM pixlar (motsvarande %dx%d pixlar).';
$lang['Manage Permissions'] = 'Hantera rättigheter';
$lang['Photo %s of %s'] = 'Bild %s av %s';
$lang['show details'] = 'visa detaljer';
$lang['hide details'] = 'dölj detaljer';
$lang['Merge tags'] = 'Sammanfoga taggar';
$lang['Select the destination tag'] = 'Välj mål-tagg';
$lang['(this tag will be deleted)'] = '(den här taggen kommer raderas)';
$lang['Confirm merge'] = 'Bekräfta sammanfogning';
$lang['Merge selected tags'] = 'Sammanfoga valda taggar';
$lang['No destination tag selected'] = 'Ingen mål-tagg har valts';
$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Taggar <em>%s</em> sammanfogade som <em>%s</em>';
$lang['Select at least two tags for merging'] = 'Välj minst två taggar för sammanfogning';
$lang['Select an album'] = 'Välj ett album';
$lang['Add a criteria'] = 'Lägg till ett kriterium';
$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'Du kan inte ange en standardsortering för foton på grund av en vald inställning i din lokala konfiguration.';
$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'Du har specifierat <i>$conf[\'order_by\']</i> i din lokala konfigurationsfil, den här parametern är ersatt. Ta bort den eller döpom till <i>$conf[\'order_by_custom\']</i> !';
$lang['All extensions are up to date.'] = 'Alla insticksmoduler är de senaste.';
$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'Följande insticksmoduler kan vara inkompatibla med senaste Piwigo:';
$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'Följande teman kan vara inkompatibla med senaste Piwigo:';
$lang['I decide to update anyway'] = 'Jag uppdaterar ändå';
$lang['Update to Piwigo %s'] = 'Uppdatera till Piwigo %s';
$lang['Two updates are available'] = 'Två uppdateringar är tillgängliga';
$lang['This is a minor update, with only bug corrections.'] = 'Det här är en mindre uppdatering med bug-fixar.';
$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Det här är en stor uppdatering med <a href="%s">nya spännande funktioner</a>.';
$lang['Some themes and plugins may be not available yet.'] = 'Några teman och insticksmoduler kan vara otillgängliga ännu.';
$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Du kan uppdatera till to Piwigo %s direkt, utan att uppgradera till Piwigo %s (rekommenderat).';
$lang['Save Template Directory'] = 'Spara mallkatalogen';
$lang['Dump Database'] = 'Dumpa databasen';
$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Inkludera historiska data (Varning: serverns minnesgräns kan överskridas)';
$lang['Unable to write new local directory.'] = 'Kan inte skriva till ny lokal katalog.';
$lang['Unable to send template directory.'] = 'Kan inte skicka mallkatalogen.';
$lang['Unable to dump database.'] = 'Kan inte dumpa databasen.';
$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'Som standard kommer Piwigo skapa en ny webbstorlek från HD (high definition) versionen av din bild.';
$lang['If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.'] = 'Om ingen HD-bild är tillgänglig och den nuvarande webbstorleken är större än skalningsdimensionerna så kommer Piwigo flytta bilden till HD och skapa en nedskalad version av den.';
$lang['An error has occured during upgrade.'] = 'Det uppstod ett fel under uppgraderingen.';
$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Ett fel uppstod vid dekomprimeringen. Kontrollera rättigheterna på din Piwigo-installation och försök igen.<br><a href="%s">Klicka här för att visa felloggen</a>.';
$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo kan inte hämta uppgraderingen från servern';
?>